Uses of Class org.openqa.selenium.server.browserlaunchers.BrowserStringParser.Result (Selenium RC Server (Coreless) 1.0.1 API)
Date: 2009-06-09

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV NEXT | FRAMES NO FRAMES

## Uses of Class
org.openqa.selenium.server.browserlaunchers.BrowserStringParser.Result

Packages that use BrowserStringParser.Result
org.openqa.selenium.server.browserlaunchers | Provides classes to launch and kill browsers.

Uses of BrowserStringParser.Result in org.openqa.selenium.server.browserlaunchers

Methods in org.openqa.selenium.server.browserlaunchers that return BrowserStringParser.Result
`BrowserStringParser.Result` | `BrowserStringParser.parseBrowserStartCommand(java.lang.String browserIdentifier, java.lang.String userBrowserSpecification)` Returns the browser start command, if any, for the browser in the 'browserString' parameter.

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV NEXT | FRAMES NO FRAMES

Copyright © 2009. All Rights Reserved.